/// <reference types="react" />
declare module "components/getDisplayName" {
    import { ComponentType } from 'react';
    const _default: <T>(hocName: string, WrappedComponent: ComponentType<T>) => string;
    export default _default;
}
declare module "components/AuthorizationProvider" {
    import React, { FunctionComponent, ReactNode } from 'react';
    import { AuthorizationProps } from 'types';
    const AuthorizationProvider: FunctionComponent<AuthorizationProps & {
        children: ReactNode;
    }>;
    export default AuthorizationProvider;
    const withAuthorization: () => <T extends object>(WrappedComponent: React.ComponentType<T & AuthorizationProps>) => React.ComponentType<T>;
    export { withAuthorization };
}
declare module "components/NavigationProvider" {
    import React, { FunctionComponent, ReactNode } from 'react';
    import { NavigatableProps, NavigationHandler } from 'types';
    const NavigationProvider: FunctionComponent<{
        onNavigate: NavigationHandler;
        children: ReactNode;
    }>;
    export default NavigationProvider;
    const withNavigation: <T extends object>() => (WrappedComponent: React.ComponentType<T & NavigatableProps>) => React.ComponentType<T & NavigatableProps>;
    export { withNavigation };
}
declare module "utils/history" {
    const _default_1: {
        push: (url: string) => void;
        length: number;
        action: import("history").Action;
        location: import("history").Location<any>;
        replace(path: string, state?: any): void;
        replace(location: import("history").LocationDescriptorObject<any>): void;
        go(n: number): void;
        goBack(): void;
        goForward(): void;
        block(prompt?: string | boolean | import("history").History.TransitionPromptHook | undefined): import("history").UnregisterCallback;
        listen(listener: import("history").History.LocationListener): import("history").UnregisterCallback;
        createHref(location: import("history").LocationDescriptorObject<any>): string;
    };
    export default _default_1;
}
declare module "utils/mediaTypes" {
    const mediaTypes: {
        any: string;
        hal: string;
        json: string;
        markdown: string;
    };
    export default mediaTypes;
}
declare module "utils/http" {
    import { HttpRequest, HttpResponse } from 'types';
    global {
        interface Headers {
            entries: () => Iterable<string>;
        }
    }
    type HttpVerb = 'get' | 'post' | 'delete';
    type Http = {
        [V in HttpVerb]: (request: HttpRequest) => Promise<HttpResponse>;
    };
    const http: Http;
    export default http;
}
declare module "utils/preventDefault" {
    const preventDefault: (cb: () => void) => (event: import("react").FormEvent<Element>) => void;
    export default preventDefault;
}
declare module "utils/hal" {
    import { HalLink, HalLinks, HalResource } from 'types';
    interface Links {
        [rel: string]: HalLink | HalLink[];
    }
    interface Embedded {
        [rel: string]: HalResource | HalResource[];
    }
    const _default_2: {
        normalizeResource: ({ _links, _embedded, ...resource }: {
            _links: Links;
            _embedded: Embedded;
        }) => HalResource;
        resolveLinks: (url: string, links: HalLinks) => HalLinks;
    };
    export default _default_2;
}
declare module "utils/reactJsonTheme" {
    import { PaletteType } from '@material-ui/core';
    import { ColorScheme } from 'base16';
    const reactJsonTheme: (type?: PaletteType) => ColorScheme;
    export default reactJsonTheme;
}
declare module "utils/clientVersion" {
    const clientVersion: string | undefined;
    export default clientVersion;
}
declare module "utils/index" {
    export { default as history } from "utils/history";
    export { default as http } from "utils/http";
    export { default as preventDefault } from "utils/preventDefault";
    export { default as mediaTypes } from "utils/mediaTypes";
    export { default as hal } from "utils/hal";
    export { default as reactJsonTheme } from "utils/reactJsonTheme";
    export { default as clientVersion } from "utils/clientVersion";
}
declare module "components/Hyperlink" {
    import { ComponentType } from 'react';
    import { HalLinks } from 'types';
    interface HyperlinkProps {
        rel: string;
        multi?: boolean;
        _links: HalLinks;
    }
    const Hyperlink: ComponentType<HyperlinkProps>;
    export default Hyperlink;
}
declare module "reactive/index" {
    import React from 'react';
    import { Observable, ReplaySubject } from 'rxjs';
    export const createAction: <T>() => ReplaySubject<T>;
    export const createState: <TState extends object>(reducer$: Observable<any>, initialState$: Observable<TState>) => Observable<TState>;
    export const connect: <TState extends object, TProps extends object = {}>(state$: Observable<TState>) => (WrappedComponent: React.ComponentType<TProps & TState>) => React.ComponentType<TProps>;
}
declare module "stream-store/rels" {
    const rels: {
        [rel: string]: string;
    };
    export default rels;
}
declare module "stream-store/navigation" {
    const _default_3: Set<string>;
    export default _default_3;
}
declare module "stream-store/actions" {
    import { ReplaySubject } from 'rxjs';
    import { HttpRequest, HttpResponse } from 'types';
    import { http } from "utils/index";
    type Actions = {
        [P in keyof typeof http]: {
            request: ReplaySubject<HttpRequest>;
            response: ReplaySubject<HttpResponse>;
        };
    };
    const actions: Actions;
    export default actions;
}
declare module "stream-store/store/mediaType" {
    const mediaType$: import("rxjs").Observable<string>;
    export default mediaType$;
}
declare module "stream-store/store/hal/body" {
    import { HalResource } from '../../../types';
    const body$: import("rxjs").Observable<HalResource>;
    export default body$;
}
declare module "stream-store/store/hal/forms" {
    import { JSONSchema7 } from 'json-schema';
    const forms$: import("rxjs").Observable<JSONSchema7>;
    export default forms$;
}
declare module "stream-store/store/hal/url" {
    const url$: import("rxjs").Observable<string>;
    export default url$;
}
declare module "stream-store/store/hal/links" {
    const links$: import("rxjs").Observable<import("types").HalLinks>;
    export default links$;
}
declare module "stream-store/store/hal/loading" {
    import { Observable as obs } from 'rxjs';
    const loading$: obs<boolean>;
    export default loading$;
}
declare module "stream-store/store/hal/index" {
    const _default_4: {
        body$: import("rxjs").Observable<import("types").HalResource>;
        forms$: import("rxjs").Observable<import("json-schema").JSONSchema7>;
        links$: import("rxjs").Observable<import("types").HalLinks>;
        loading$: import("rxjs").Observable<boolean>;
        url$: import("rxjs").Observable<string>;
    };
    export default _default_4;
}
declare module "stream-store/store/markdown" {
    const _default_5: {
        body$: import("rxjs").Observable<string | object | undefined>;
    };
    export default _default_5;
}
declare module "stream-store/store/index" {
    const _default_6: {
        hal$: {
            body$: import("rxjs").Observable<import("types").HalResource>;
            forms$: import("rxjs").Observable<import("json-schema").JSONSchema7>;
            links$: import("rxjs").Observable<import("types").HalLinks>;
            loading$: import("rxjs").Observable<boolean>;
            url$: import("rxjs").Observable<string>;
        };
        markdown$: {
            body$: import("rxjs").Observable<string | object | undefined>;
        };
        mediaType$: import("rxjs").Observable<string>;
    };
    export default _default_6;
}
declare module "stream-store/Viewer/HalViewer/Home" {
    import React from 'react';
    import { HalViewerProps } from './types';
    const _default_7: React.ComponentType<HalViewerProps>;
    export default _default_7;
}
declare module "stream-store/Viewer/HalViewer/components/StreamHeader" {
    const StreamHeader: () => JSX.Element;
    export default StreamHeader;
}
declare module "stream-store/Viewer/HalViewer/components/StreamMessageDetails" {
    import { FunctionComponent } from 'react';
    import { HalResource } from 'types';
    interface StreamMessageDetailsProps {
        messageId: string;
        createdUtc: string;
        position: number;
        streamId: string;
        streamVersion: number;
        type: string;
    }
    const StreamMessageDetails: FunctionComponent<StreamMessageDetailsProps & HalResource>;
    export default StreamMessageDetails;
}
declare module "themes" {
    import { Theme } from '@material-ui/core';
    import { Observable } from 'rxjs';
    const _default_8: {
        actions: {
            type: import("rxjs").ReplaySubject<void>;
        };
        defaultTheme: Theme;
        theme$: Observable<Theme>;
    };
    export default _default_8;
}
declare module "stream-store/Viewer/HalViewer/components/JsonViewer" {
    import React from 'react';
    interface JsonViewerProps {
        json?: object;
    }
    const _default_9: React.ComponentType<JsonViewerProps>;
    export default _default_9;
}
declare module "stream-store/Viewer/HalViewer/components/index" {
    export { default as StreamHeader } from "stream-store/Viewer/HalViewer/components/StreamHeader";
    export { default as StreamMessageDetails } from "stream-store/Viewer/HalViewer/components/StreamMessageDetails";
    export { default as JsonViewer } from "stream-store/Viewer/HalViewer/components/JsonViewer";
}
declare module "stream-store/Viewer/HalViewer/Stream" {
    import React from 'react';
    import { HalViewerProps } from './types';
    const _default_10: React.ComponentType<HalViewerProps>;
    export default _default_10;
}
declare module "stream-store/Viewer/HalViewer/StreamBrowser" {
    import React from 'react';
    import { HalViewerProps } from './types';
    const _default_11: React.ComponentType<HalViewerProps>;
    export default _default_11;
}
declare module "icons/SqlStreamStore" {
    import { SvgIconProps } from '@material-ui/core/SvgIcon';
    import { ComponentType } from 'react';
    const SqlStreamStore: ComponentType<SvgIconProps>;
    export default SqlStreamStore;
}
declare module "icons/mui/LightbulbFull" {
    import { SvgIconProps } from '@material-ui/core/SvgIcon';
    const LightbulbFull: (props: SvgIconProps) => JSX.Element;
    export default LightbulbFull;
}
declare module "icons/mui/LightbulbOutline" {
    import { SvgIconProps } from '@material-ui/core/SvgIcon';
    const LightbulbOutline: {
        (props: SvgIconProps): JSX.Element;
        muiName: string;
    };
    export default LightbulbOutline;
}
declare module "icons/mui/index" {
    export { default as LightbulbFull } from "icons/mui/LightbulbFull";
    export { default as LightbulbOutline } from "icons/mui/LightbulbOutline";
}
declare module "icons/index" {
    export { default as SqlStreamStore } from "icons/SqlStreamStore";
    export { default as Code } from '@material-ui/icons/Code';
    export { default as Close } from '@material-ui/icons/Close';
    export { default as CheckCircle } from '@material-ui/icons/CheckCircle';
    export { default as Warning } from '@material-ui/icons/Warning';
    export { default as Error } from '@material-ui/icons/Error';
    export { default as Info } from '@material-ui/icons/Info';
    export { default as Publish } from '@material-ui/icons/Publish';
    export { default as Settings } from '@material-ui/icons/Settings';
    export { default as Notes } from '@material-ui/icons/Notes';
    export { default as DeleteForever } from '@material-ui/icons/DeleteForever';
    export { default as FirstPage } from '@material-ui/icons/FirstPage';
    export { default as LastPage } from '@material-ui/icons/LastPage';
    export { default as ChevronLeft } from '@material-ui/icons/ChevronLeft';
    export { default as ChevronRight } from '@material-ui/icons/ChevronRight';
    export { default as RssFeed } from '@material-ui/icons/RssFeed';
    export { default as Refresh } from '@material-ui/icons/Refresh';
    export { default as SpaceBar } from '@material-ui/icons/SpaceBar';
    export { default as Search } from '@material-ui/icons/Search';
    export { default as List } from '@material-ui/icons/List';
    export { default as Help } from '@material-ui/icons/Help';
    export { LightbulbFull, LightbulbOutline } from "icons/mui/index";
}
declare module "stream-store/Viewer/HalViewer/StreamMessage" {
    import React from 'react';
    import { HalViewerProps } from './types';
    const _default_12: React.ComponentType<HalViewerProps>;
    export default _default_12;
}
declare module "stream-store/Viewer/HalViewer/StreamMetadata" {
    import React from 'react';
    import { HalViewerProps } from './types';
    const _default_13: React.ComponentType<HalViewerProps>;
    export default _default_13;
}
declare module "stream-store/Viewer/HalViewer/Unrecognized" {
    import React from 'react';
    import { HalViewerProps } from './types';
    const _default_14: React.ComponentType<HalViewerProps>;
    export default _default_14;
}
declare module "stream-store/Viewer/HalViewer/index" {
    import { FunctionComponent } from 'react';
    import { HalViewerProps } from './types';
    const HalViewer: FunctionComponent<HalViewerProps>;
    export default HalViewer;
}
declare module "stream-store/Viewer/MarkdownViewer/index" {
    import React from 'react';
    const _default_15: React.ComponentType<{}>;
    export default _default_15;
}
declare module "stream-store/Viewer/index" {
    const Viewer: ({ mediaType, ...props }: {
        mediaType: string;
    }) => import("react").ReactElement<{}, string | ((props: any) => import("react").ReactElement<any, string | any | (new (props: any) => import("react").Component<any, any, any>)> | null) | (new (props: any) => import("react").Component<any, any, any>)>;
    export default Viewer;
}
declare module "stream-store/index" {
    export { default as rels } from "stream-store/rels";
    export { default as navigation } from "stream-store/navigation";
    export { default as store } from "stream-store/store/index";
    export { default as actions } from "stream-store/actions";
    export { default as Viewer } from "stream-store/Viewer/index";
}
declare module "components/RelIcon" {
    import { SvgIconProps } from '@material-ui/core/SvgIcon';
    import { ComponentType } from 'react';
    interface RelIconProps {
        rel: string;
    }
    const RelIcon: ComponentType<RelIconProps & SvgIconProps>;
    export default RelIcon;
}
declare module "components/HyperMediaControls/HelpButton" {
    import React from 'react';
    import { HalLink } from 'types';
    interface HelpButtonProps {
        rel: string;
        curies: HalLink[];
        disabled?: boolean;
        authorization?: string;
    }
    const _default_16: React.ComponentType<HelpButtonProps>;
    export default _default_16;
}
declare module "components/HyperMediaControls/RelButton" {
    import { ButtonProps } from '@material-ui/core/Button';
    import { FunctionComponent } from 'react';
    interface RelButtonProps {
        rel: string;
        title?: string;
    }
    const RelButton: FunctionComponent<RelButtonProps & ButtonProps>;
    export default RelButton;
}
declare module "components/HyperMediaControls/Dialog" {
    import React from 'react';
    import { HalLink } from 'types';
    interface HyperMediaDialogProps {
        rel: string;
        title?: string;
        curies: HalLink[];
        onSubmit: () => void;
    }
    const _default_17: React.ComponentType<Pick<HyperMediaDialogProps & {
        classes: Record<"button", string>;
        innerRef?: ((instance: any) => void) | React.RefObject<any> | null | undefined;
    }, "title" | "onSubmit" | "rel" | "curies"> & import("@material-ui/core").StyledComponentProps<"button">>;
    export default _default_17;
}
declare module "components/HyperMediaControls/TextAreaField" {
    import React from 'react';
    import { ReactSchemaFormInputProps } from 'react-schema-form';
    const _default_18: React.ComponentType<ReactSchemaFormInputProps<HTMLInputElement | HTMLSelectElement | HTMLTextAreaElement>>;
    export default _default_18;
}
declare module "components/HyperMediaControls/UuidField" {
    import React from 'react';
    import { ReactSchemaFormInputProps } from 'react-schema-form';
    const _default_19: React.ComponentType<ReactSchemaFormInputProps<HTMLInputElement | HTMLSelectElement | HTMLTextAreaElement>>;
    export default _default_19;
}
declare module "components/HyperMediaControls/FormButton" {
    import { JSONSchema7 } from 'json-schema';
    import React from 'react';
    import { FormActions, HalLink } from 'types';
    interface FormButtonProps {
        rel: string;
        link: HalLink;
        actions: FormActions;
        curies: HalLink[];
        schema: JSONSchema7;
    }
    const _default_20: React.ComponentType<FormButtonProps>;
    export default _default_20;
}
declare module "components/HyperMediaControls/LinkButton" {
    import { PropTypes } from '@material-ui/core';
    import { HalLink } from 'types';
    import Color = PropTypes.Color;
    interface LinkButtonProps {
        readonly rel: string;
        readonly link: HalLink;
        color: Color;
    }
    interface TemplatedLinkButtonProps extends LinkButtonProps {
        readonly curies: HalLink[];
    }
    interface NonTemplatedLinkButtonProps extends LinkButtonProps {
        readonly title: string;
    }
    const _default_21: ({ link, ...props }: TemplatedLinkButtonProps | NonTemplatedLinkButtonProps) => JSX.Element;
    export default _default_21;
}
declare module "components/HyperMediaControls/index" {
    import { JSONSchema7 } from 'json-schema';
    import React from 'react';
    import { FormActions, HalLinks, HalResource } from 'types';
    interface HyperMediaControlsProps {
        actions: FormActions;
        _links: HalLinks;
        forms: {
            [rel: string]: HalResource & JSONSchema7;
        };
    }
    const _default_22: React.ComponentType<HyperMediaControlsProps>;
    export default _default_22;
}
declare module "components/Loading" {
    const Loading: ({ open }: {
        open: boolean;
    }) => JSX.Element;
    export default Loading;
}
declare module "components/NavigationLinks" {
    import { FunctionComponent } from 'react';
    import { HalLinks } from 'types';
    interface NavigationLinksProps {
        _links: HalLinks;
    }
    const NavigationLinks: FunctionComponent<NavigationLinksProps>;
    export default NavigationLinks;
}
declare module "components/Notifications" {
    import React from 'react';
    const _default_23: React.ComponentType<{}>;
    export default _default_23;
}
declare module "components/StreamBrowser" {
    import React from 'react';
    import { HalResource } from 'types';
    interface StreamBrowserProps {
        loading: boolean;
        streams: HalResource[];
    }
    const _default_24: React.ComponentType<StreamBrowserProps>;
    export default _default_24;
}
declare module "components/StripeyTable/index" {
    import { TableProps } from '@material-ui/core/Table';
    import { TableRowProps } from '@material-ui/core/TableRow';
    import React, { PureComponent } from 'react';
    class StripeyTable extends PureComponent<TableProps> {
        static Body: React.ComponentType<import("@material-ui/core/TableBody").TableBodyProps>;
        static Row: React.ComponentType<Pick<TableRowProps & {
            classes: Record<"row", string>;
            innerRef?: ((instance: any) => void) | React.RefObject<any> | null | undefined;
        }, "hidden" | "dir" | "slot" | "style" | "title" | "color" | "children" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "className" | "contentEditable" | "contextMenu" | "draggable" | "id" | "lang" | "placeholder" | "spellCheck" | "tabIndex" | "inputMode" | "is" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "component" | "selected" | "hover"> & import("@material-ui/core").StyledComponentProps<"row">>;
        static Cell: React.ComponentType<(Pick<import("@material-ui/core/TableCell").TableCellProps, "hidden" | "dir" | "slot" | "style" | "title" | "color" | "padding" | "numeric" | "children" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "className" | "contentEditable" | "contextMenu" | "draggable" | "id" | "lang" | "placeholder" | "spellCheck" | "tabIndex" | "inputMode" | "is" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "component" | "align" | "variant" | "colSpan" | "headers" | "rowSpan" | "scope" | "sortDirection"> & import("@material-ui/core").StyledComponentProps<never>) | (Pick<import("@material-ui/core/TableCell").TableCellProps & {
            children?: React.ReactNode;
        }, "hidden" | "dir" | "slot" | "style" | "title" | "color" | "padding" | "numeric" | "children" | "defaultChecked" | "defaultValue" | "suppressContentEditableWarning" | "suppressHydrationWarning" | "accessKey" | "className" | "contentEditable" | "contextMenu" | "draggable" | "id" | "lang" | "placeholder" | "spellCheck" | "tabIndex" | "inputMode" | "is" | "radioGroup" | "role" | "about" | "datatype" | "inlist" | "prefix" | "property" | "resource" | "typeof" | "vocab" | "autoCapitalize" | "autoCorrect" | "autoSave" | "itemProp" | "itemScope" | "itemType" | "itemID" | "itemRef" | "results" | "security" | "unselectable" | "aria-activedescendant" | "aria-atomic" | "aria-autocomplete" | "aria-busy" | "aria-checked" | "aria-colcount" | "aria-colindex" | "aria-colspan" | "aria-controls" | "aria-current" | "aria-describedby" | "aria-details" | "aria-disabled" | "aria-dropeffect" | "aria-errormessage" | "aria-expanded" | "aria-flowto" | "aria-grabbed" | "aria-haspopup" | "aria-hidden" | "aria-invalid" | "aria-keyshortcuts" | "aria-label" | "aria-labelledby" | "aria-level" | "aria-live" | "aria-modal" | "aria-multiline" | "aria-multiselectable" | "aria-orientation" | "aria-owns" | "aria-placeholder" | "aria-posinset" | "aria-pressed" | "aria-readonly" | "aria-relevant" | "aria-required" | "aria-roledescription" | "aria-rowcount" | "aria-rowindex" | "aria-rowspan" | "aria-selected" | "aria-setsize" | "aria-sort" | "aria-valuemax" | "aria-valuemin" | "aria-valuenow" | "aria-valuetext" | "dangerouslySetInnerHTML" | "onCopy" | "onCopyCapture" | "onCut" | "onCutCapture" | "onPaste" | "onPasteCapture" | "onCompositionEnd" | "onCompositionEndCapture" | "onCompositionStart" | "onCompositionStartCapture" | "onCompositionUpdate" | "onCompositionUpdateCapture" | "onFocus" | "onFocusCapture" | "onBlur" | "onBlurCapture" | "onChange" | "onChangeCapture" | "onBeforeInput" | "onBeforeInputCapture" | "onInput" | "onInputCapture" | "onReset" | "onResetCapture" | "onSubmit" | "onSubmitCapture" | "onInvalid" | "onInvalidCapture" | "onLoad" | "onLoadCapture" | "onError" | "onErrorCapture" | "onKeyDown" | "onKeyDownCapture" | "onKeyPress" | "onKeyPressCapture" | "onKeyUp" | "onKeyUpCapture" | "onAbort" | "onAbortCapture" | "onCanPlay" | "onCanPlayCapture" | "onCanPlayThrough" | "onCanPlayThroughCapture" | "onDurationChange" | "onDurationChangeCapture" | "onEmptied" | "onEmptiedCapture" | "onEncrypted" | "onEncryptedCapture" | "onEnded" | "onEndedCapture" | "onLoadedData" | "onLoadedDataCapture" | "onLoadedMetadata" | "onLoadedMetadataCapture" | "onLoadStart" | "onLoadStartCapture" | "onPause" | "onPauseCapture" | "onPlay" | "onPlayCapture" | "onPlaying" | "onPlayingCapture" | "onProgress" | "onProgressCapture" | "onRateChange" | "onRateChangeCapture" | "onSeeked" | "onSeekedCapture" | "onSeeking" | "onSeekingCapture" | "onStalled" | "onStalledCapture" | "onSuspend" | "onSuspendCapture" | "onTimeUpdate" | "onTimeUpdateCapture" | "onVolumeChange" | "onVolumeChangeCapture" | "onWaiting" | "onWaitingCapture" | "onClick" | "onClickCapture" | "onContextMenu" | "onContextMenuCapture" | "onDoubleClick" | "onDoubleClickCapture" | "onDrag" | "onDragCapture" | "onDragEnd" | "onDragEndCapture" | "onDragEnter" | "onDragEnterCapture" | "onDragExit" | "onDragExitCapture" | "onDragLeave" | "onDragLeaveCapture" | "onDragOver" | "onDragOverCapture" | "onDragStart" | "onDragStartCapture" | "onDrop" | "onDropCapture" | "onMouseDown" | "onMouseDownCapture" | "onMouseEnter" | "onMouseLeave" | "onMouseMove" | "onMouseMoveCapture" | "onMouseOut" | "onMouseOutCapture" | "onMouseOver" | "onMouseOverCapture" | "onMouseUp" | "onMouseUpCapture" | "onSelect" | "onSelectCapture" | "onTouchCancel" | "onTouchCancelCapture" | "onTouchEnd" | "onTouchEndCapture" | "onTouchMove" | "onTouchMoveCapture" | "onTouchStart" | "onTouchStartCapture" | "onPointerDown" | "onPointerDownCapture" | "onPointerMove" | "onPointerMoveCapture" | "onPointerUp" | "onPointerUpCapture" | "onPointerCancel" | "onPointerCancelCapture" | "onPointerEnter" | "onPointerEnterCapture" | "onPointerLeave" | "onPointerLeaveCapture" | "onPointerOver" | "onPointerOverCapture" | "onPointerOut" | "onPointerOutCapture" | "onGotPointerCapture" | "onGotPointerCaptureCapture" | "onLostPointerCapture" | "onLostPointerCaptureCapture" | "onScroll" | "onScrollCapture" | "onWheel" | "onWheelCapture" | "onAnimationStart" | "onAnimationStartCapture" | "onAnimationEnd" | "onAnimationEndCapture" | "onAnimationIteration" | "onAnimationIterationCapture" | "onTransitionEnd" | "onTransitionEndCapture" | "component" | "align" | "variant" | "colSpan" | "headers" | "rowSpan" | "scope" | "sortDirection"> & import("@material-ui/core").StyledComponentProps<never>)>;
        static Head: React.ComponentType<import("@material-ui/core/TableHead").TableHeadProps>;
        static Footer: React.ComponentType<import("@material-ui/core/TableFooter").TableFooterProps>;
        render(): JSX.Element;
    }
    export default StripeyTable;
}
declare module "components/index" {
    import AuthorizationProvider, { withAuthorization } from "components/AuthorizationProvider";
    import NavigationProvider, { withNavigation } from "components/NavigationProvider";
    export { AuthorizationProvider, withAuthorization };
    export { default as Hyperlink } from "components/Hyperlink";
    export { default as HyperMediaControls } from "components/HyperMediaControls/index";
    export { default as Loading } from "components/Loading";
    export { default as NavigationLinks } from "components/NavigationLinks";
    export { NavigationProvider, withNavigation };
    export { default as Notifications } from "components/Notifications";
    export { default as StreamBrowser } from "components/StreamBrowser";
    export { default as Table } from "components/StripeyTable/index";
}
declare module "SqlStreamStoreBrowser" {
    import { Theme } from '@material-ui/core';
    import { JSONSchema7 } from 'json-schema';
    import React, { ComponentType } from 'react';
    import { AuthorizationProps, HalLink, HalLinks } from './types';
    interface SqlStreamStoreBrowserState {
        loading: boolean;
        mediaType: string;
        _links: HalLinks;
        self: HalLink;
        theme: Theme;
        forms: {
            [rel: string]: JSONSchema7;
        };
    }
    export const AuthorizedSqlStreamStoreBrowser: ComponentType<SqlStreamStoreBrowserState & AuthorizationProps>;
    const _default_25: React.ComponentType<AuthorizationProps>;
    export default _default_25;
}
declare module "TestBrowser" {
    import { PureComponent } from 'react';
    export default class TestBrowser extends PureComponent<{}, {}> {
        render(): JSX.Element;
    }
}
declare module "index" {
    import React from 'react';
    import ReactDOM from 'react-dom';
    import SqlStreamStoreBrowser from "SqlStreamStoreBrowser";
    import TestBrowser from "TestBrowser";
    global {
        interface Window {
            React: typeof React;
            ReactDOM: typeof ReactDOM;
            SqlStreamStoreBrowser: typeof SqlStreamStoreBrowser;
            TestBrowser: typeof TestBrowser;
        }
    }
    export default TestBrowser;
}
declare module "stream-store/store/hal/streamBrowser" { }
